@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h,v 1.78 2005/09/09 16:02:48 mbarbon Exp $
+// RCS-ID:      $Id: helpers.h,v 1.79 2006/07/16 12:26:16 mbarbon Exp $
 // Copyright:   (c) 2000-2005 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -17,12 +17,8 @@
 #include <wx/list.h>
 #include <wx/gdicmn.h>
 
-#if wxUSE_STL
 #include <wx/dynarray.h>
 #include <wx/arrstr.h>
-#else
-class WXDLLEXPORT wxArrayInt;
-#endif
 
 class wxPliUserDataCD;
 class wxPliTreeItemData;
