@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     27/07/2001
-## RCS-ID:      $Id: XRC.pm,v 1.11 2004/02/29 14:30:40 mbarbon Exp $
-## Copyright:   (c) 2001-2003 Mattia Barbon
+## RCS-ID:      $Id: XRC.pm,v 1.13 2006/06/29 20:57:52 mbarbon Exp $
+## Copyright:   (c) 2001-2004 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -40,7 +40,7 @@ Wx::XmlInitResourceModule();
 no strict;
 
 package Wx::PlXmlResourceHandler; @ISA = qw(Wx::XmlResourceHandler);
-package Wx::PliXmlSubclassFactory; @IAS = qw(Wx::XmlSubclassFactory);
+package Wx::PliXmlSubclassFactory; @ISA = qw(Wx::XmlSubclassFactory);
 
 use strict;
 
